.input-group span.twitter-typeahead {
	display: block !important;
}
.input-group span.twitter-typeahead .tt-menu {
	top: 32px !important;
}
.input-group.input-group-sm .tt-menu {
	top: 28px !important;
}
.input-group.input-group-lg .tt-menu {
	top: 44px !important;
}
.tt-menu {
	background-clip: padding-box;
	background-color: #ffffff;
	border-radius: 4px;
	border: 1px solid #cccccc;
	box-shadow: 0 6px 12px #cccccc;
	display: none;
	float: left;
	font-size: 14px;
	left: 0;
	list-style: none;
	margin: 2px 0 0;
	min-width: 160px;
	padding: 5px 0;
	position: absolute;
	text-align: left;
	top: 100%;
	width: 100%;
	z-index: 1000;
}
.tt-hint {
	color: #cccccc;
}
.tt-suggestion.tt-cursor {
	background-color: #f6f6f6;
}
span.twitter-typeahead {
	width: 100%;
}
