.login-icon {
	color: #4D5E69;
	font-size: 50px;
	font-weight: 100;
	margin-top: -20px;
	margin-bottom: 20px;
	text-align: center;
}
.login-wrapper {
	height: 400px;
	left: 50%;
	margin-left: -200px;
	margin-top: -200px;
	position: fixed;
	top: 50%;
	width: 400px;
}
form.login, div.logout {
	background-color: white;
	border-radius: 50px;
	box-shadow: 0 0 80px 0 rgba(0, 0, 0, 0.1);
	padding: 60px;
}
div.logout {
	text-align: center;
}
form.login .form-control, form.login button {
	position: relative;
	height: auto;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	padding: 10px;
	font-size: 16px;
}
form.login .form-control:focus {
	z-index: 3;
}
form.login input[type="text"] {
	margin-bottom: -1px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0;
}
form.login input[type="password"] {
	margin-bottom: 10px;
	border-top-left-radius: 0;
	border-top-right-radius: 0;
}
form.login button {
	border-top-right-radius: 0;
	color: #3F5D79;
	margin-top: -10px;
	z-index: 2;
}
form.login button:hover {
	color: #443c70;
}
