# Generated by Django 2.0 on 2018-02-20 10:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('secrets', '0014_auto_20170313_1544'),
    ]

    operations = [
        migrations.AddField(
            model_name='secretrevision',
            name='plaintext_data_sha256',
            field=models.CharField(default='<unknown>', max_length=64),
            preserve_default=False,
        ),
    ]
