{% load smart_pagination %}
{% if is_paginated %}
<ul class="pagination">
	{% if page_obj.has_previous %}
	<li><a href="?{% replace_get_param page=page_obj.previous_page_number %}"><i class="fa fa-chevron-left"></i></a></li>
	{% else %}
	<li class="disabled"><a href="#"><i class="fa fa-chevron-left"></i></a></li>
	{% endif %}
	{% for page in paginator.page_range|smart_pages:page_obj.number %}
	{% if page_obj.number == page %}
	<li class="active"><a href="#">{{ page }} <span class="sr-only">(current)</span></a></li>
	{% else %}
	<li><a href="?{% replace_get_param page=page %}">{{ page }}</a></li>
	{% endif %}
	{% endfor %}
	{% if page_obj.has_next %}
	<li><a href="?{% replace_get_param page=page_obj.next_page_number %}"><i class="fa fa-chevron-right"></i></a></li>
	{% else %}
	<li class="disabled"><a href="#"><i class="fa fa-chevron-right"></i></a></li>
	{% endif %}
</ul>
{% endif %}
