{% extends "base_nav.html" %}
{% load humanize %}
{% load i18n %}
{% load staticfiles %}
{% load smart_pagination %}
{% block "title" %}{% trans "Browse" %}{% endblock %}
{% block "nav_browse" %}active{% endblock %}
{% block "content" %}
<script>
	$(document).ready(function() {
		$('#search').select();
	});
</script>
<div class="container">
	<div class="row">
		<div class="col-md-12">
			<h1>
				{% if request.GET.search %}
				{% blocktrans with search=request.GET.search %}Search results for '{{ search }}'...{% endblocktrans %}
				{% else %}
				{% trans "Browse all items" %}
				{% endif %}

			</h1>
			{{ page_obj.paginator.count }} item(s) found
			<br><br>
			<div class="panel panel-default">
				<table class="table table-hover secret-list">
					{% for secret in secrets %}
					{% include "secrets/secret_row.html" %}
					{% endfor %}
				</table>
			</div>
			{% include "pagination.html" %}
		</div>
	</div>
</div>
{% endblock %}
