# Generated by Django 2.0 on 2018-02-20 14:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('secrets', '0020_auto_20180220_1356'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='secret',
            name='owner_groups',
        ),
        migrations.RemoveField(
            model_name='secret',
            name='owner_users',
        ),
    ]
