body {
	font-family: Roboto, Helvetica, sans-serif;
}
.background {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	background-size: cover;
	background-position: 50% 50%;
	background: #e6edf2;
	background: -moz-linear-gradient(top,  #e6edf2 0%, #ffffff 100%);
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#e6edf2), color-stop(100%,#ffffff));
	background: -webkit-linear-gradient(top,  #e6edf2 0%,#ffffff 100%);
	background: -o-linear-gradient(top,  #e6edf2 0%,#ffffff 100%);
	background: -ms-linear-gradient(top,  #e6edf2 0%,#ffffff 100%);
	background: linear-gradient(to bottom,  #e6edf2 0%,#ffffff 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e6edf2', endColorstr='#ffffff',GradientType=0 );
}
.container-opaque {
	background-color: white;
}
img.avatar {
	border: 0px solid black;
	border-radius: 16px;
	height: 32px;
	width: 32px;
	margin-top: -10px;
	margin-bottom: -8px;
}
.dropdown-menu i {
	color: #92A6B2;
}
h1 {
	color: #505050;
}
h1>.badge {
	vertical-align: top;
}
.secret-list tr td:last-child {
	white-space: nowrap;
	width: 1px;
}
footer {
	color: #cccccc;
	font-size: 10px;
	text-align: center;
	padding-top: 100px;
	padding-bottom: 20px;
}
