# Generated by Django 2.0 on 2018-02-20 13:56

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('secrets', '0018_auto_20180220_1244'),
    ]

    operations = [
        migrations.AddField(
            model_name='secret',
            name='notify_on_access_request',
            field=models.ManyToManyField(blank=True, related_name='notify_on_access_requests_for', to=settings.AUTH_USER_MODEL),
        ),
    ]
