{% load i18n %}
<tr>
	<td class="secret-list-icons">
		&nbsp;
		{% if secret not in readable_secrets %}
		<i class="fa fa-lock"></i>&nbsp;
		{% endif %}
		{% if secret.content_type == secret.CONTENT_PASSWORD %}
		<i class="fa fa-user"></i>
		{% elif secret.content_type == secret.CONTENT_FILE %}
		<i class="fa fa-file"></i>
		{% elif secret.content_type == secret.CONTENT_CC %}
		<i class="fa fa-credit-card"></i>
		{% endif %}
	</td>
	<td>
		<a href="{{ secret.get_absolute_url }}">
			{{ secret.name }}
		</a>
	</td>
	<td>
		{% if secret.username %}
		<span class="secret-list-detail">{{ secret.username }}</span>
		{% endif %}
		{% if secret.filename %}
		<span class="secret-list-detail">{{ secret.filename }}</span>
		{% endif %}
	</td>
	<td>
		{% if secret.status == secret.STATUS_DELETED %}
		<span class="text-danger-bright"><i class="fa fa-trash"></i></span>&nbsp;
		{% elif secret.status == secret.STATUS_NEEDS_CHANGING %}
		<span class="text-danger-bright"><i class="fa fa-refresh"></i></span>&nbsp;
		{% endif %}
	</td>
</tr>
