{% extends "base.html" %}
{% load i18n %}
{% load staticfiles %}
{% block "title" %}{% trans "Login" %}{% endblock %}
{% block "global_content" %}
<div class="container">
	<div class="background"></div>
	<div class="login-wrapper">
		<form id="loginform" class="login" role="form" method="POST">
			<div class="login-icon">{% trans "TeamVault" %}</div>
			{% if form.errors %}
			<p>{% trans "Your username and password didn't match. Please try again." %}</p>
			{% endif %}
			<input type="text" name="username" class="form-control" placeholder="{% trans "Username" %}" required autofocus>

			<div class="input-group">
				<input type="password" name="password" class="form-control" placeholder="{% trans "Password" %}" required>
				<span class="input-group-btn">
					<button form="loginform" class="btn btn-default" type="submit"><i class="fa fa-chevron-right"></i></button>
				</span>
			</div>
			{% csrf_token %}
		</form>
	</div>
</div>
{% endblock %}
