{% extends "base_nav.html" %}
{% load i18n %}
{% load staticfiles %}
{% block "title" %}{% trans "Dashboard" %}{% endblock %}
{% block "content" %}
<script>
	$(document).ready(function() {
		$('#search').select();
	});
</script>
<div class="container container-opaque">
	<div class="row">
		<div class="col-md-6">
			<h3>{% trans "Recently used secrets" %}</h3>
			<div class="panel panel-default">
				<table class="table table-hover secret-list">
					{% for secret in recently_used_secrets %}
					{% include "secrets/secret_row.html" %}
					{% endfor %}
				</table>
			</div>
		</div>
		<div class="col-md-6">
			<h3>{% trans "Most used secrets" %}</h3>
			<div class="panel panel-default">
				<table class="table table-hover secret-list">
					{% for secret in most_used_secrets %}
					{% include "secrets/secret_row.html" %}
					{% endfor %}
				</table>
			</div>
		</div>
	</div>
</div>
{% endblock %}
