{% extends "secrets/secret_addedit.html" %}
{% load i18n %}
{% block "content_type_fields" %}
<div class="form-group">
	<div class="col-sm-2">
		<label class="control-label" for="id_password">{% trans "Password" %}</label>
	</div>
	<div class="col-sm-6">
		<div class="input-group">
			<input class="form-control" id="id_password" name="password" placeholder="{% if secret %}{% trans "(unchanged)" %}{% else %}**************{% endif %}" {% if not secret %}required="required"{% endif %} type="password" value="{% if form.is_bound and not secret %}{{ form.password.value }}{% endif %}">
			<span class="input-group-addon" style="border-left: 0;" title="{% trans "Password strength" %}" id="id_password_strength"><i class="fa fa-star-o text-muted"></i><i class="fa fa-star-o text-muted"></i><i class="fa fa-star-o text-muted"></i><i class="fa fa-star-o text-muted"></i><i class="fa fa-star-o text-muted"></i></span>
			<span class="input-group-btn">
				<button class="btn btn-default" id="id_pwgen" type="button" title="{% trans "Generate random password" %}"><i class="fa fa-refresh"></i></button>
			</span>
		</div>
	</div>
	<div class="col-sm-4">
		<p class="form-control-static"><i class="fa fa-lock"></i> &nbsp; {% trans "This field will be stored securely." %}</p>
	</div>
</div>
<div class="form-group">
	<div class="col-sm-2">
		<label class="control-label" for="id_username">{% trans "Username" %}</label>
	</div>
	<div class="col-sm-6">
		<input class="form-control" id="id_username" name="username" placeholder="{% trans "(optional)" %}" value="{{ form.username.value|default_if_none:"" }}" type="text">
	</div>
	<div class="col-sm-4">
		<p class="form-control-static"><i class="fa fa-search"></i> &nbsp; {% trans "This field will also be considered when searching." %}</p>
	</div>
</div>
<div class="form-group secret-details">
	<div class="col-sm-2">
		<label class="control-label" for="id_url">{% trans "URL" %}</label>
	</div>
	<div class="col-sm-6">
		<input class="form-control" id="id_url" name="url" placeholder="{% trans "(optional)" %}" value="{{ form.url.value|default_if_none:"" }}" type="url">
	</div>
	<div class="col-sm-4">
		<p class="form-control-static"><i class="fa fa-search"></i> &nbsp; {% trans "This field will also be considered when searching." %}</p>
	</div>
</div>
{% endblock %}
