# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-09-30 10:41
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('secrets', '0009_auto_20150322_0949'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='secret',
            name='search_index',
        ),
    ]
