{% extends "base_nav.html" %}
{% load i18n %}
{% load staticfiles %}
{% block "title" %}{% trans "Confirm restore" %}{% endblock %}
{% block "content" %}
<div class="container container-opaque">
	<div class="row">
		<div class="col-md-8 col-md-offset-2">
			<h1>
				{% blocktrans with name=secret.name content_type=secret.get_content_type_display %}
				Restore {{ content_type }} '{{ name }}'?
				{% endblocktrans %}
			</h1>
			<hr>
		</div>
	</div>
	<div class="row">
		<div class="col-md-8 col-md-offset-2">
			<div class="alert alert-info" role="alert">
				{% blocktrans %}
				The secret will be restored with its current permissions. Please be sure that the secret should be restored and become visible to users.
				{% endblocktrans %}
			</div>
			<form role="form" method="POST" class="form-horizontal">
				{% csrf_token %}
				<a class="btn btn-default btn-lg pull-left" href="{{ secret.get_absolute_url }}"><i class="fa fa-angle-left"></i> &nbsp; {% trans "No, go back" %}</a>
				<button type="submit" class="btn btn-danger btn-lg pull-right"><i class="fa fa-undo"></i> &nbsp; {% trans "Yes, restore" %}</button>
			</form>
		</div>
	</div>
</div>
{% endblock %}
